==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/WyrownanieWplataKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class WyrownanieWplataKey extends GenericDPSObject {
    /**
     * WYROWNANIE_WPLATA.WPLATA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wplataId;

    /**
     * WYROWNANIE_WPLATA.WYROWNANIE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long wyrownanieId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WYROWNANIE_WPLATA.WPLATA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * WYROWNANIE_WPLATA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return WYROWNANIE_WPLATA.WYROWNANIE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getWyrownanieId() {
        return wyrownanieId;
    }

    /**
     * WYROWNANIE_WPLATA.WYROWNANIE_ID
     *
     * @param wyrownanieId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setWyrownanieId(Long wyrownanieId) {
        this.wyrownanieId = wyrownanieId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WyrownanieWplataKey other = (WyrownanieWplataKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getWyrownanieId() == null ? other.getWyrownanieId() == null : this.getWyrownanieId().equals(other.getWyrownanieId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getWyrownanieId() == null) ? 0 : getWyrownanieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", wyrownanieId=").append(wyrownanieId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/WyrownanieWplataKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class WyrownanieWplataKey extends GenericDPSObject {
    /**
     * WYROWNANIE_WPLATA.WPLATA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wplataId;

    /**
     * WYROWNANIE_WPLATA.WYROWNANIE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long wyrownanieId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return WYROWNANIE_WPLATA.WPLATA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWplataId() {
        return wplataId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * WYROWNANIE_WPLATA.WPLATA_ID
     *
     * @param wplataId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWplataId(Long wplataId) {
        this.wplataId = wplataId;
    }

    /**
     * @return WYROWNANIE_WPLATA.WYROWNANIE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getWyrownanieId() {
        return wyrownanieId;
    }

    /**
     * WYROWNANIE_WPLATA.WYROWNANIE_ID
     *
     * @param wyrownanieId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setWyrownanieId(Long wyrownanieId) {
        this.wyrownanieId = wyrownanieId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        WyrownanieWplataKey other = (WyrownanieWplataKey) that;
        return (this.getWplataId() == null ? other.getWplataId() == null : this.getWplataId().equals(other.getWplataId()))
            && (this.getWyrownanieId() == null ? other.getWyrownanieId() == null : this.getWyrownanieId().equals(other.getWyrownanieId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getWplataId() == null) ? 0 : getWplataId().hashCode());
        result = prime * result + ((getWyrownanieId() == null) ? 0 : getWyrownanieId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", wplataId=").append(wplataId);
        sb.append(", wyrownanieId=").append(wyrownanieId);
        sb.append("]");
        return sb.toString();
    }
}
